@@ -2,15 +2,18 @@
 import os
 import sys
 from pathlib import Path
-from typing import Any, NoReturn
+from typing import Any, NoReturn, Optional, Type
 
 import click
 from pygitguardian import GGClient
 
+from ggshield.output import JSONHandler, OutputHandler, TextHandler
+
 from .ci import ci_cmd
-from .config import CONTEXT_SETTINGS, Config, load_dot_env
+from .config import CONTEXT_SETTINGS, Cache, Config, load_dot_env
 from .dev_scan import path_cmd, precommit_cmd, range_cmd, repo_cmd
 from .filter import path_filter_set
+from .ignore import ignore
 from .install import install
 
 
@@ -34,9 +37,17 @@ from .install import install
     is_flag=True,
     default=None,
     envvar="GITGUARDIAN_EXIT_ZERO",
-    help="Always return a 0 (non-error) status code, even if issues are found."
+    help="Always return a 0 (non-error) status code, even if incidents are found."
     "The env var GITGUARDIAN_EXIT_ZERO can also be used to set this option.",
 )
+@click.option(
+    "--json",
+    "json_output",
+    is_flag=True,
+    default=False,
+    show_default=True,
+    help="JSON output results",
+)
 @click.option(
     "--all-policies",
     is_flag=True,
@@ -45,7 +56,14 @@ from .install import install
     "By default, only Secret Detection is shown.",
 )
 @click.option(
-    "--verbose", "-v", is_flag=True, default=None, help="Verbose display mode.",
+    "--verbose", "-v", is_flag=True, default=None, help="Verbose display mode."
+)
+@click.option(
+    "--output",
+    "-o",
+    type=click.Path(exists=False, resolve_path=True),
+    default=None,
+    help="Route ggshield output to file.",
 )
 @click.pass_context
 def scan(
@@ -54,6 +72,8 @@ def scan(
     exit_zero: bool,
     all_policies: bool,
     verbose: bool,
+    json_output: bool,
+    output: Optional[str],
 ) -> int:
     """ Command to scan various contents. """
     api_key = os.getenv("GITGUARDIAN_API_KEY")
@@ -69,17 +89,27 @@ def scan(
     ctx.obj["filter_set"] = path_filter_set(
         Path(os.getcwd()), ctx.obj["config"].paths_ignore
     )
+    config: Config = ctx.obj["config"]
+
     if show_secrets is not None:
-        ctx.obj["config"].show_secrets = show_secrets
+        config.show_secrets = show_secrets
 
     if all_policies is not None:
-        ctx.obj["config"].all_policies = all_policies
+        config.all_policies = all_policies
 
     if verbose is not None:
-        ctx.obj["config"].verbose = verbose
+        config.verbose = verbose
 
     if exit_zero is not None:
-        ctx.obj["config"].exit_zero = exit_zero
+        config.exit_zero = exit_zero
+
+    output_handler_cls: Type[OutputHandler] = TextHandler
+    if json_output:
+        output_handler_cls = JSONHandler
+
+    ctx.obj["output_handler"] = output_handler_cls(
+        show_secrets=config.show_secrets, verbose=config.verbose, output=output
+    )
 
     return return_code
 
@@ -99,7 +129,8 @@ def exit_code(ctx: click.Context, exit_code: int, **kwargs: Any) -> None:
 
 
 @click.group(
-    context_settings=CONTEXT_SETTINGS, commands={"scan": scan, "install": install}
+    context_settings=CONTEXT_SETTINGS,
+    commands={"scan": scan, "install": install, "ignore": ignore},
 )
 @click.option(
     "-c",
@@ -108,7 +139,7 @@ def exit_code(ctx: click.Context, exit_code: int, **kwargs: Any) -> None:
     help="Set a custom config file. Ignores local and global config files.",
 )
 @click.option(
-    "--verbose", "-v", is_flag=True, default=None, help="Verbose display mode.",
+    "--verbose", "-v", is_flag=True, default=None, help="Verbose display mode."
 )
 @click.pass_context
 def cli(ctx: click.Context, config_path: str, verbose: bool) -> None:
@@ -119,6 +150,7 @@ def cli(ctx: click.Context, config_path: str, verbose: bool) -> None:
         Config.CONFIG_GLOBAL = []
 
     ctx.obj["config"] = Config()
+    ctx.obj["cache"] = Cache()
 
     if verbose is not None:
         ctx.obj["config"].verbose = verbose
