@@ -11,6 +11,15 @@ REGEX_PATCH_HEADER = re.compile(
     r"^(?P<line_content>@@ -(?P<pre_index>\d+),?\d* \+(?P<post_index>\d+),?\d* @@(?: .+)?)"  # noqa
 )
 
+# Source: https://github.com/jonschlinkert/is-git-url MIT LICENSE
+REGEX_GIT_URL = re.compile(
+    r"(?:git|ssh|https?|git@[-\w.]+):(\/\/)?(.*?)(\.git)(\/?|\#[-\d\w._]+?)$"
+)
+
+REGEX_HEADER_INFO = re.compile(
+    r"Author:\s(?P<author>.+?)\ <(?P<email>.+?)>\nDate:\s+(?P<date>.+)?\n"
+)
+
 
 class Filemode(Enum):
     """
@@ -28,14 +37,14 @@ class Filemode(Enum):
     PERMISSION_CHANGE = (7, "changed permissions")
     FILE = (0, "file")
 
-    def __init__(self, start, mode):
+    def __init__(self, start: int, mode: str):
         self.start = start
         self.mode = mode
 
 
 def get_lines_from_content(
     content: str, filemode: Filemode, is_patch: bool, show_secrets: bool
-) -> List[str]:
+) -> List[Line]:
     """
     Return the secrets and the lines with line number.
 
@@ -60,7 +69,7 @@ def get_lines_from_file(content: str) -> Iterable[Line]:
         )
 
 
-def get_lines_from_patch(content: str, filemode: Filemode) -> List:
+def get_lines_from_patch(content: str, filemode: Filemode) -> Iterable[Line]:
     """ Return the lines with line number from a git patch. """
     content += "\n"
     pre_index = 0
@@ -71,6 +80,7 @@ def get_lines_from_patch(content: str, filemode: Filemode) -> List:
         line_content = ""
         line_pre_index = None
         line_post_index = None
+        category = None
 
         if line_type == " ":
             line_content = line[1:]
@@ -78,21 +88,18 @@ def get_lines_from_patch(content: str, filemode: Filemode) -> List:
             post_index += 1
             line_pre_index = pre_index
             line_post_index = post_index
-
         elif line_type == "@":
             m = REGEX_PATCH_HEADER.search(line)
-            pre_index = m.groupdict()["pre_index"]
-            post_index = m.groupdict()["post_index"]
+            if m is None:
+                continue
+            pre_index = int(m.groupdict()["pre_index"])
+            post_index = int(m.groupdict()["post_index"])
             line_content = m.groupdict()["line_content"][:-1]
 
             if filemode == Filemode.NEW or filemode == Filemode.DELETE:
                 pre_index = 1
                 post_index = 1
 
-            else:
-                pre_index = int(pre_index)
-                post_index = int(post_index)
-
             if line_content:
                 line_type = " "
                 pre_index -= 1
@@ -100,13 +107,11 @@ def get_lines_from_patch(content: str, filemode: Filemode) -> List:
                 line_pre_index = None
                 line_post_index = None
                 category = LineCategory.empty
-
         elif line_type == "+":
             post_index += 1
             line_post_index = post_index
             line_content = line[1:]
             category = LineCategory.addition
-
         elif line_type == "-":
             pre_index += 1
             line_pre_index = pre_index
@@ -124,7 +129,7 @@ def get_lines_from_patch(content: str, filemode: Filemode) -> List:
 
 def update_policy_break_matches(
     matches: List[Match], lines: List[Line], is_patch: bool
-):
+) -> None:
     """
     Update secrets object with secret line and indexes in line.
 
@@ -136,7 +141,7 @@ def update_policy_break_matches(
     line_index = 0
 
     for match in matches:
-        if not match.index_start:
+        if match.index_start is None:
             continue
         len_line = len(lines[line_index].content) + 1 + int(is_patch)
         # Update line_index until we find the secret start
